; *****************************************************************************
; Plot the distribution of wavlet coefficients as function of angle and scale
pro angularhist, name, type, scales=scalesfile, stretch=stretch, unit=unit

; Parameters for plotting routines
; ---------------------------------------
; name is the base name of the original fits file
; type is the letter indicating the analysis type, e.g. different edge treatment
; 	Example: name="test", type="A" 
;	searches for a file of wavelet coefficients "test_allconvolved_A.fits" 
; scales can specify a scales file other than "scales.dat"
; stretch expands the scale axis by the factor stretch
; unit specifies the scale unit label if stretch is used
; tpos gives the position of labels (1,2,3,4=lu,ru,ll,rl)
; scaled normalizes the wavelet coefficients by (sigma_map^2 * s^2)

; get scales
if n_elements(scalesfile) lt 1 then scalesfile="scales.dat"
readcol, scalesfile, numi, scales
nscal=n_elements(scales)

; definition of scale axis to allow for pc instead of pixels
if keyword_set(stretch) then begin
  mult=stretch
  if n_elements(unit) lt 1 then unit="pc" 
endif else begin
  unit="pixels"
  mult=1.0
endelse

; Get and fix map
map=readfits(name+".fits",hdr)
nmap=n_elements(map)
norm=total(map^2,/nan) 

; get fields of m
phifeld=getangles(name,type,isotropic=dtmp)

; result fields
nbin=72. ; angular bins
dx=!pi/(2.0*nbin)
histarr=fltarr(nscal,nbin)
histarr2=fltarr(nscal,nbin)

; Compute histogram for degree
degree=fltarr(nmap,nscal)
for j=0,nscal-1 do begin &$
  degree[*,j]=phifeld[*,j,1]/total(dtmp[*,*,j],/nan) &$
  temphist=histogram(phifeld[*,j,0],nbins=nbin,min=-!pi/2,max=!pi/2,$
    /nan, locations=vbins, reverse_indices=rind) &$
  for k=0,nbin-1 do $
    if (k lt n_elements(rind)-1) then $
      if (rind[k+1] gt rind[k]) then $
        histarr[j,k]=total(degree[rind[rind[k]:rind[k+1]-1],j]) &$
endfor

; Compute histograms for spectra
for j=0,nscal-1 do begin &$
  temphist=histogram(phifeld[*,j,0],nbins=nbin,min=-!pi/2,max=!pi/2,$
    /nan, locations=vbins, reverse_indices=rind) &$
  for k=0,nbin-1 do $
    if (k lt n_elements(rind)-1) then $
      if (rind[k+1] gt rind[k]) then $
        histarr2[j,k]=total(phifeld[rind[rind[k]:rind[k+1]-1],j,1]) &$
endfor

; normalize, remove the insigificant point at Pi/2
vbins=(vbins[0:nbin-2]+dx)
histarr=histarr[*,0:nbin-2]
histarr2=histarr2[*,0:nbin-2]/norm
hmax=max(histarr2)

; plot
tmax="max[A(s,!4u!3)]="+strcompress(string(hmax,format='(G8.2)'),/remove_all)
overlay, histarr, scales*mult, vbins, /xlog, /noaspect, $
	titles=["s ["+unit+"]","!4u!3","!S!U!20&!3!N!RA(s,!4u!3)",tmax], $
	grid=grid, nlevels=0 
overcontour, histarr2, scales*mult, vbins, /nolabels, /xlog, $
	grid=grid, levels=[hmax/30.,hmax/10.,hmax/3.], color=1

return
end


; *****************************************************************************
; Plot the degrees of anisotropy
pro plotdegrees, name, type, tpos=tpos, scales=scalesfile, $
	stretch=stretch, unit=unit

; get scales
if n_elements(scalesfile) lt 1 then scalesfile="scales.dat"
readcol, scalesfile, numi, scales

; definition of scale axis to allow for pc instead of pixels
if keyword_set(stretch) then begin
  mult=stretch
  if n_elements(unit) lt 1 then unit="pc"
endif else begin
  unit="pixels"
  mult=1.0
endelse

; fields of m
dglobal1=getdegree(name,type,local=dlocal1)

; plot
if n_elements(tpos) eq 0 then tpos=2
plot, scales*mult,dlocal1, psym=3, /xlog, xrange=[min(scales)*0.75,max(scales)*1.2]*mult, $
	yrange=[0,1], xtitle="s ["+unit+"]", ytitle="d!Danisotropy!N", /xst, /yst 
numplot, scales*mult,dlocal1, 0, title="d!S!Dloc"+"!R!Uw!N", tpos=tpos, /connect
numplot, scales*mult,dglobal1, 1, title="d!S!Dglob"+"!R!Uw!N", tpos=tpos, /connect

return
end

; *****************************************************************************
; Plot isotropic and anisotropic spectra
pro plotspectra, name, type, tpos=tpos, scales=scalesfile, $
	stretch=stretch, scaled=scaled, unit=unit

; definition of scale axis to allow for pc instead of pixels
if n_elements(scalesfile) lt 1 then scalesfile="scales.dat"
if keyword_set(stretch) then begin
  mult=stretch
  if n_elements(unit) lt 1 then unit="pc"
endif else begin
  unit="pixels"
  mult=1.0
endelse

; get scales
readcol, scalesfile, numi, scales

; Get and fix map
map=readfits(name+".fits",hdr)
inv=where(~ finite(map), count)
if count gt 0 then map[inv]=0.0

; Two different types of scaling M or M/s^2
if keyword_set(scaled) then begin
  norm=variance(map,/nan)
  factors=scales^2*norm
  ytit="M/(!4r!3!Df!U2!N s!U2!N)"
endif else begin
  factors=scales*0.0+1.0
  ytit="energy density"
endelse

; get fields of m; weighting is done there already
dan=getspectra(name,type,isotropic=diso)

; plot
if n_elements(tpos) eq 0 then tpos=1
ymax=max(diso/factors,/nan)
yrange=[(min(dan/factors,/nan) > ymax*1e-10) < ymax*1e-3,ymax]
plot, scales*mult, diso/factors, psym=3, /xlog, /ylog, $
	xrange=[min(scales)*0.75,max(scales)*1.2]*mult, yrange=yrange, $
	xtitle="s ["+unit+"]", ytitle=ytit, /xst
numplot, scales*mult, diso/factors, 0, title="M!Ii!N", tpos=tpos, /connect
numplot, scales*mult, dan/factors, 1, title="M!Ua!N", tpos=tpos, /connect

return
end

